package com.playmore.game.util;

import com.playmore.db.BaseDataDaoImpl;
import com.playmore.db.BaseGameDaoImpl;
import com.playmore.game.db.manager.AbstractDataProvider;
import com.playmore.game.db.manager.AbstractRecordCacheProvider;
import com.playmore.game.db.manager.GameDataManager;
import com.playmore.game.db.manager.GameUserManager;
import com.playmore.game.db.manager.IGameDataProvider;
import com.playmore.game.general.code.ErrorCode;
import com.playmore.game.general.code.OperaCode;
import com.playmore.game.general.constants.ActivityConstants;
import com.playmore.game.general.constants.ChannelSwitchContants;
import com.playmore.game.general.constants.GameConstants;
import com.playmore.game.general.constants.GoodsConstants;
import com.playmore.game.general.constants.GroupConstants;
import com.playmore.game.general.constants.RechargeConstants;
import com.playmore.game.general.constants.ResourceConstants;
import com.playmore.game.general.constants.SwitchContants;
import com.playmore.game.user.activity.CommActivityProvider;
import com.playmore.tool.CheckDBUtil;
import com.playmore.tool.DataActivityType;
import com.playmore.tool.DataChannelSwitch;
import com.playmore.tool.DataGroup;
import com.playmore.tool.DataSwitch;
import com.playmore.tool.DataType;
import com.playmore.tool.GenerateUtil;
import com.playmore.tool.obj.BaseFrame;
import com.playmore.tool.obj.ComboItem;
import com.playmore.tool.obj.DBUser;
import com.playmore.util.DesUtil;
import com.playmore.util.PropertiesUtil;
import com.playmore.util.PropertyUtil;
import com.playmore.util.StringUtil;
import java.awt.Component;
import java.awt.EventQueue;
import java.util.ArrayList;
import java.util.List;
import java.util.Properties;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.UIManager;

public class GameUtil extends JFrame {

   private static final long serialVersionUID = 1L;


   public static void main(String[] agrs) throws Exception {
      EventQueue.invokeLater(new Runnable() {
         public void run() {
            try {
               UIManager.setLookAndFeel("com.sun.java.swing.plaf.nimbus.NimbusLookAndFeel");
               (new GameUtil.GameFrame()).init();
            } catch (Throwable var2) {
               var2.printStackTrace();
               JOptionPane.showMessageDialog((Component)null, "异常：" + var2.getMessage());
            }
         }
      });
   }

   public static class GameFrame extends BaseFrame {

      private static final long serialVersionUID = 1L;
      private JCheckBox datatemp = new JCheckBox();
      private List userList = new ArrayList();
      private List dataList = new ArrayList();


      protected void addComponent(JPanel panel) {
         this.initDB();
         panel.add(this.label);
         this.comboItems.add(this.daoItem());
         this.comboItems.add(this.checkUserItem());
         this.comboItems.add(this.generateMergeItem());
         this.comboItems.add(this.errorItem());
         this.comboItems.add(this.operaItem());
         this.comboItems.add(this.switchItem());
         this.comboItems.add(this.resourceItem());
         this.comboItems.add(this.switchChannelItem());
         this.comboItems.add(this.groupItem());
         this.comboItems.add(this.actTypeItem());
         this.comboItems.add(this.typeItem());
         panel.add(this.comboBox);
         panel.add(this.button);
         panel.add(this.checkBox);
         panel.add(this.endlabel);
         panel.add(this.endComboBox);
         panel.add(this.datatemp);
         this.datatemp.setSelected(true);
      }

      private void initDB() {
         if(this.userList.isEmpty()) {
            try {
               String e = PropertyUtil.getSysPath(this.getClass());
               Properties properties = PropertiesUtil.read(e + "/src/global.config");
               String url = properties.getProperty("game.bonecp.jdbcUrl", "");
               String username = properties.getProperty("game.bonecp.username", "");
               String password = properties.getProperty("game.bonecp.password", "");
               DesUtil desUtil = new DesUtil();
               this.userList.add(new DBUser("玩家库", url, username, desUtil.decrypt(password)));
               url = properties.getProperty("static.bonecp.jdbcUrl", "");
               username = properties.getProperty("static.bonecp.username", "");
               password = properties.getProperty("static.bonecp.password", "");
               this.dataList.add(new DBUser("静态库", url, username, desUtil.decrypt(password)));
            } catch (Throwable var7) {
               var7.printStackTrace();
            }
         }

      }

      protected int changeSubBounds() {
         this.clearLog();
         this.label.setBounds(0, 20, 60, 27);
         this.comboBox.setBounds(60, 20, 150, 27);
         this.button.setBounds(230, 20, 80, 27);
         return ((ComboItem)this.comboItems.get(this.comboBox.getSelectedIndex())).changeBounds();
      }

      protected void addSubListener() {
         this.button.addActionListener(this);
         this.comboBox.addActionListener(this);
      }

      protected void handler(Object target) {
         if(target == this.button) {
            String text = this.button.getText();
            this.setEnabled(this.button, (String)null, false);

            try {
               this.clearLog();
               ((ComboItem)this.comboItems.get(this.comboBox.getSelectedIndex())).exec();
            } finally {
               this.setEnabled(this.button, text, false);
            }
         } else if(target == this.comboBox) {
            this.changeBounds();
            ((ComboItem)this.comboItems.get(this.comboBox.getSelectedIndex())).show();
         }

      }

      public ComboItem daoItem() {
         final JComponent[] hides = new JComponent[]{this.endlabel, this.endComboBox, this.checkBox, this.datatemp};
         return new ComboItem("生成daoImpl", (JComponent[])null, hides) {
            public void exec() {
               try {
                  GameFrame.this.info("generate user daoImpl ...");
                  GenerateUtil.generateDaoImpl(BaseGameDaoImpl.class, "com/playmore/game/db/user", "db.xml", GameFrame.this.logHandle);
                  GameFrame.this.info("generate user daoImpl ok!\r\n");
                  GameFrame.this.info("generate user provider ...");
                  GenerateUtil.generateProviderImpl(IGameDataProvider.class, "com/playmore/game/db/user", "db_cache.xml", GameUserManager.class, GameFrame.this.logHandle);
                  GenerateUtil.generateProviderImpl(CommActivityProvider.class, "com/playmore/game/db/user", "db_cache.xml", GameUserManager.class, GameFrame.this.logHandle);
                  GenerateUtil.generateProviderImpl(AbstractRecordCacheProvider.class, "com/playmore/game/db/user", "db_cache.xml", GameUserManager.class, GameFrame.this.logHandle);
                  GameFrame.this.info("generate user provider ok!\r\n");
               } catch (Exception var3) {
                  JOptionPane.showMessageDialog((Component)null, "异常：\r\n" + StringUtil.toString(var3));
                  return;
               }

               try {
                  GameFrame.this.info("generate data daoImpl ...");
                  GenerateUtil.generateDaoImpl(BaseDataDaoImpl.class, "com/playmore/game/db/data", "static_db.xml", GameFrame.this.logHandle);
                  GameFrame.this.info("generate data daoImpl ok!\r\n");
                  GameFrame.this.info("generate data provider ...");
                  GenerateUtil.generateProviderImpl(AbstractDataProvider.class, "com/playmore/game/db/data", "static_cache.xml", GameDataManager.class, GameFrame.this.logHandle);
                  GameFrame.this.info("generate data provider ok!\r\n");
               } catch (Exception var2) {
                  JOptionPane.showMessageDialog((Component)null, "异常：\r\n" + StringUtil.toString(var2));
               }
            }
            public int changeBounds() {
               return 50;
            }
         };
      }

      public ComboItem errorItem() {
         final JComponent[] shows = new JComponent[]{this.endlabel, this.endComboBox};
         final JComponent[] hides = new JComponent[]{this.checkBox, this.datatemp};
         return new ComboItem("生成错误码", shows, hides) {
            public void exec() {
               try {
                  DBUser e = (DBUser)GameFrame.this.ucList.get(GameFrame.this.endComboBox.getSelectedIndex());
                  GameFrame.this.info("错误码生成处理 " + e.getDbname() + " ...");
                  if(!GenerateUtil.generateErrorCodeByLua(e, ErrorCode.class, GameFrame.this.logHandle)) {
                     GameFrame.this.info("错误码处理完毕，无差异!");
                  } else {
                     GameFrame.this.info("错误码处理完毕!");
                  }

               } catch (Exception var2) {
                  JOptionPane.showMessageDialog((Component)null, "异常：\r\n" + StringUtil.toString(var2));
               }
            }
            public int changeBounds() {
               GameFrame.this.initComboBox(GameFrame.this.endComboBox, GameFrame.this.ucList);
               GameFrame.this.endlabel.setBounds(0, 50, 60, 27);
               GameFrame.this.endComboBox.setBounds(60, 50, 250, 27);
               return 80;
            }
         };
      }

      public ComboItem operaItem() {
         final JComponent[] shows = new JComponent[]{this.endlabel, this.endComboBox};
         final JComponent[] hides = new JComponent[]{this.checkBox, this.datatemp};
         return new ComboItem("生成操作码", shows, hides) {
            public void exec() {
               try {
                  DBUser e = (DBUser)GameFrame.this.ucList.get(GameFrame.this.endComboBox.getSelectedIndex());
                  GameFrame.this.info("操作码生成处理： " + e.getDbname() + " ...");
                  if(!GenerateUtil.generateOperaCode(e, OperaCode.class, GameFrame.this.logHandle)) {
                     GameFrame.this.info("操作码处理完毕，无差异!");
                  } else {
                     GameFrame.this.info("操作码处理完毕!");
                  }

               } catch (Exception var2) {
                  JOptionPane.showMessageDialog((Component)null, "异常：\r\n" + StringUtil.toString(var2));
               }
            }
            public int changeBounds() {
               GameFrame.this.initComboBox(GameFrame.this.endComboBox, GameFrame.this.ucList);
               GameFrame.this.endlabel.setBounds(0, 50, 60, 27);
               GameFrame.this.endComboBox.setBounds(60, 50, 250, 27);
               return 80;
            }
         };
      }

      public ComboItem resourceItem() {
         final JComponent[] shows = new JComponent[]{this.endlabel, this.endComboBox};
         final JComponent[] hides = new JComponent[]{this.checkBox, this.datatemp};
         return new ComboItem("生成资源类型", shows, hides) {
            public void exec() {
               try {
                  DBUser e = (DBUser)GameFrame.this.ucList.get(GameFrame.this.endComboBox.getSelectedIndex());
                  GameFrame.this.info("资源类型生成处理： " + e.getDbname() + " ...");
                  if(!GenerateUtil.generateResourceType(e, ResourceConstants.class, GameFrame.this.logHandle)) {
                     GameFrame.this.info("资源类型处理完毕，无差异!");
                  } else {
                     GameFrame.this.info("资源类型处理完毕!");
                  }

               } catch (Exception var2) {
                  JOptionPane.showMessageDialog((Component)null, "异常：\r\n" + StringUtil.toString(var2));
               }
            }
            public int changeBounds() {
               GameFrame.this.initComboBox(GameFrame.this.endComboBox, GameFrame.this.ucList);
               GameFrame.this.endlabel.setBounds(0, 50, 60, 27);
               GameFrame.this.endComboBox.setBounds(60, 50, 250, 27);
               return 80;
            }
         };
      }

      public ComboItem switchItem() {
         final JComponent[] shows = new JComponent[]{this.endlabel, this.endComboBox};
         final JComponent[] hides = new JComponent[]{this.checkBox, this.datatemp};
         return new ComboItem("生成服务器开关", shows, hides) {
            public void exec() {
               try {
                  DBUser e = (DBUser)GameFrame.this.ucList.get(GameFrame.this.endComboBox.getSelectedIndex());
                  GameFrame.this.info("服务器开关检查生成： " + e.getDbname() + " ...");
                  if(!GenerateUtil.generateSwitch(e, SwitchContants.class, DataSwitch.class, GameFrame.this.logHandle)) {
                     GameFrame.this.info("服务器开关处理完毕，无差异!");
                  } else {
                     GameFrame.this.info("服务器开关处理完毕!");
                  }

               } catch (Exception var2) {
                  JOptionPane.showMessageDialog((Component)null, "异常：\r\n" + StringUtil.toString(var2));
               }
            }
            public int changeBounds() {
               GameFrame.this.initComboBox(GameFrame.this.endComboBox, GameFrame.this.ucList);
               GameFrame.this.endlabel.setBounds(0, 50, 60, 27);
               GameFrame.this.endComboBox.setBounds(60, 50, 250, 27);
               return 80;
            }
         };
      }

      public ComboItem switchChannelItem() {
         final JComponent[] shows = new JComponent[]{this.endlabel, this.endComboBox};
         final JComponent[] hides = new JComponent[]{this.checkBox, this.datatemp};
         return new ComboItem("生成渠道开关", shows, hides) {
            public void exec() {
               try {
                  DBUser e = (DBUser)GameFrame.this.ucList.get(GameFrame.this.endComboBox.getSelectedIndex());
                  GameFrame.this.info("渠道开关检查生成： " + e.getDbname() + " ...");
                  if(!GenerateUtil.generateSwitch(e, ChannelSwitchContants.class, DataChannelSwitch.class, GameFrame.this.logHandle)) {
                     GameFrame.this.info("渠道开关处理完毕，无差异!");
                  } else {
                     GameFrame.this.info("渠道开关处理完毕!");
                  }

               } catch (Exception var2) {
                  JOptionPane.showMessageDialog((Component)null, "异常：\r\n" + StringUtil.toString(var2));
               }
            }
            public int changeBounds() {
               GameFrame.this.initComboBox(GameFrame.this.endComboBox, GameFrame.this.ucList);
               GameFrame.this.endlabel.setBounds(0, 50, 60, 27);
               GameFrame.this.endComboBox.setBounds(60, 50, 250, 27);
               return 80;
            }
         };
      }

      public ComboItem checkUserItem() {
         final JComponent[] shows = new JComponent[]{this.endlabel, this.endComboBox};
         final JComponent[] hides = new JComponent[]{this.checkBox, this.datatemp};
         return new ComboItem("检查玩家库", shows, hides) {
            public void exec() {
               try {
                  DBUser e = (DBUser)GameFrame.this.userList.get(GameFrame.this.endComboBox.getSelectedIndex());
                  GameFrame.this.info("#检查玩家库: " + e.getDbname() + " : \r\n");
                  String result = CheckDBUtil.checkBase(e, "com/playmore/game/db", GameFrame.this.logHandle);
                  if(result == null) {
                     GameFrame.this.info("检查玩家库完毕，无差异!");
                  } else {
                     GameFrame.this.info(result);
                  }

               } catch (Exception var3) {
                  JOptionPane.showMessageDialog((Component)null, "异常：\r\n" + StringUtil.toString(var3));
               }
            }
            public int changeBounds() {
               GameFrame.this.initComboBox(GameFrame.this.endComboBox, GameFrame.this.userList);
               GameFrame.this.endlabel.setBounds(0, 50, 60, 27);
               GameFrame.this.endComboBox.setBounds(60, 50, 250, 27);
               return 80;
            }
         };
      }

      public ComboItem generateMergeItem() {
         final JComponent[] shows = new JComponent[]{this.endlabel, this.endComboBox};
         final JComponent[] hides = new JComponent[]{this.checkBox, this.datatemp};
         return new ComboItem("合服表生成", shows, hides) {
            public void exec() {
               try {
                  DBUser e = (DBUser)GameFrame.this.ucList.get(GameFrame.this.endComboBox.getSelectedIndex());
                  GameFrame.this.info("#玩家库合服表生成: " + e.getDbname() + " : \r\n");
                  String result = GenerateUtil.generateMergeTables(e, "com/playmore/game/db", GameFrame.this.logHandle);
                  if(result == null) {
                     GameFrame.this.info("玩家库合服表生成检查完毕，无差异!");
                  } else {
                     GameFrame.this.info(result);
                  }

               } catch (Exception var3) {
                  JOptionPane.showMessageDialog((Component)null, "异常：\r\n" + StringUtil.toString(var3));
               }
            }
            public int changeBounds() {
               GameFrame.this.initComboBox(GameFrame.this.endComboBox, GameFrame.this.ucList);
               GameFrame.this.endlabel.setBounds(0, 50, 60, 27);
               GameFrame.this.endComboBox.setBounds(60, 50, 250, 27);
               return 80;
            }
         };
      }

      public ComboItem groupItem() {
         final JComponent[] shows = new JComponent[]{this.endlabel, this.endComboBox};
         final JComponent[] hides = new JComponent[]{this.checkBox};
         return new ComboItem("生成跨服分组", shows, hides) {
            public void exec() {
               try {
                  DBUser e = (DBUser)GameFrame.this.ucList.get(GameFrame.this.endComboBox.getSelectedIndex());
                  GameFrame.this.info("generate " + e.getDbname() + " server switch ...");
                  GenerateUtil.generateGroup(e, GroupConstants.class, DataGroup.class, GameFrame.this.logHandle);
                  GameFrame.this.info("generate server group ok!");
               } catch (Exception var2) {
                  JOptionPane.showMessageDialog((Component)null, "异常：\r\n" + StringUtil.toString(var2));
               }
            }
            public int changeBounds() {
               GameFrame.this.initComboBox(GameFrame.this.endComboBox, GameFrame.this.ucList);
               GameFrame.this.endlabel.setBounds(0, 50, 60, 27);
               GameFrame.this.endComboBox.setBounds(60, 50, 250, 27);
               return 80;
            }
         };
      }

      public ComboItem actTypeItem() {
         final JComponent[] shows = new JComponent[]{this.endlabel, this.endComboBox};
         final JComponent[] hides = new JComponent[]{this.checkBox, this.datatemp};
         return new ComboItem("生成活动类型", shows, hides) {
            public void exec() {
               try {
                  DBUser e = (DBUser)GameFrame.this.ucList.get(GameFrame.this.endComboBox.getSelectedIndex());
                  GameFrame.this.info("活动类型生成： " + e.getDbname() + " ...");
                  if(!GenerateUtil.generateActType(e, ActivityConstants.class, DataActivityType.class, GameFrame.this.logHandle)) {
                     GameFrame.this.info("活动类型处理完毕，无差异!");
                  }

               } catch (Exception var2) {
                  JOptionPane.showMessageDialog((Component)null, "异常：\r\n" + StringUtil.toString(var2));
               }
            }
            public int changeBounds() {
               GameFrame.this.initComboBox(GameFrame.this.endComboBox, GameFrame.this.ucList);
               GameFrame.this.endlabel.setBounds(0, 50, 60, 27);
               GameFrame.this.endComboBox.setBounds(60, 50, 250, 27);
               return 80;
            }
         };
      }

      public ComboItem typeItem() {
         final JComponent[] shows = new JComponent[]{this.endlabel, this.endComboBox};
         final JComponent[] hides = new JComponent[]{this.checkBox, this.datatemp};
         return new ComboItem("类型名称", shows, hides) {
            public void exec() {
               try {
                  DBUser e = (DBUser)GameFrame.this.ucList.get(GameFrame.this.endComboBox.getSelectedIndex());
                  GameFrame.this.info("类型名称： " + e.getDbname() + " ...");
                  GenerateUtil.generateType(e, GameConstants.class, 1, RechargeConstants.class, "OtherRechargeType", DataType.class, GameFrame.this.logHandle);
                  GenerateUtil.generateType(e, GameConstants.class, 2, RechargeConstants.class, "PriceType", DataType.class, GameFrame.this.logHandle);
                  GenerateUtil.generateType(e, GameConstants.class, 3, GoodsConstants.class, "Type", DataType.class, GameFrame.this.logHandle);
                  GameFrame.this.info("处理完毕!");
               } catch (Exception var2) {
                  JOptionPane.showMessageDialog((Component)null, "异常：\r\n" + StringUtil.toString(var2));
               }
            }
            public int changeBounds() {
               GameFrame.this.initComboBox(GameFrame.this.endComboBox, GameFrame.this.ucList);
               GameFrame.this.endlabel.setBounds(0, 50, 60, 27);
               GameFrame.this.endComboBox.setBounds(60, 50, 250, 27);
               return 80;
            }
         };
      }

      public void setEnabled(JButton curButtion, String text, boolean cross) {
         boolean enabled = text != null;
         if(enabled) {
            curButtion.setText(text);
         } else {
            curButtion.setText("处理中...");
         }

         this.comboBox.setEnabled(enabled);
         this.button.setEnabled(enabled);
         if(this.endComboBox.isVisible()) {
            this.endComboBox.setEnabled(enabled);
         }

         if(this.checkBox.isVisible()) {
            this.checkBox.setEnabled(enabled);
         }

      }
   }
}
